@@ -1,5 +1,6 @@
+/* $Id: grid.c 4 2008-06-22 09:19:11Z rbock $ */
 /* GtkDatabox - An extension to the gtk+ library
- * Copyright (C) 1998 - 2007  Dr. Roland Bock
+ * Copyright (C) 1998 - 2008  Dr. Roland Bock
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -50,7 +51,7 @@ create_grid (void)
    gtk_widget_set_size_request (window, 500, 500);
 
    g_signal_connect (GTK_OBJECT (window), "destroy",
-		     GTK_SIGNAL_FUNC (gtk_main_quit), NULL);
+		     G_CALLBACK (gtk_main_quit), NULL);
 
    gtk_window_set_title (GTK_WINDOW (window),
 			 "GtkDatabox: Double Grid Example");
@@ -129,7 +130,7 @@ create_grid (void)
    gtk_box_pack_end (GTK_BOX (box1), box2, FALSE, TRUE, 0);
    close_button = gtk_button_new_with_label ("close");
    g_signal_connect_swapped (GTK_OBJECT (close_button), "clicked",
-			     GTK_SIGNAL_FUNC (gtk_main_quit),
+			     G_CALLBACK (gtk_main_quit),
 			     GTK_OBJECT (box));
    gtk_box_pack_start (GTK_BOX (box2), close_button, TRUE, TRUE, 0);
    GTK_WIDGET_SET_FLAGS (close_button, GTK_CAN_DEFAULT);
